@@ -60,6 +60,9 @@ import time
 from Exceptions import *
 from PyQt4.QtCore import *
 
+g_orietation = 0
+
+
 #these are for testing
 #INSTALL_PATH="/home/user/MyDocs/maebo/src/maebo/"
 #DATA_FILE_PATH="/home/user/MyDocs/maebo/test/"
@@ -97,10 +100,19 @@ ROLE_TEST_OPERATION=90
 ROLE_OPERATION=89
 ROLE_TEST_GAP=88
 
+ROLE_CM_NUM=83
+ROLE_RT_NUM=84
+
 SETTINGS_ATT_NAMES=[
         "downpic",
         "updatenum"
         ]
+        
+STATUS_ATT_COUNTS=[
+        "id",
+        "comments",
+        "rt",
+        ]
 
 STATUS_ATT_NAMES=[
         "status_id",
@@ -128,6 +140,10 @@ STATUS_ATT_NAMES=[
         "original_pic",
         "user",
         "retweeted_status",
+        "cm_num",
+        "rt_num",
+        "status",
+        "reply_comment",
         ]
 USER_ATT_NAMES=[
         "user_id",
@@ -169,12 +185,14 @@ ACCOUNT_ATT_NAMES=[
 STATUS_OPE_TYPE_UPDATE=1
 STATUS_OPE_TYPE_MORE=2
 STATUS_OPE_TYPE_GAP=3
+STATUS_OPE_TYPE_COMMENT=3
 
 TIMELINE_TYPE_FRIENDS=1
 TIMELINE_TYPE_DM=2
 TIMELINE_TYPE_MENTIONS=3
 TIMELINE_TYPE_COMMENTS=4
 TIMELINE_TYPE_FAVOUR=5
+TIMELINE_TYPE_ST_COMMENTS=6
 
 NEW_A_STATUS=11
 
@@ -275,11 +293,13 @@ def build_an_account_from_row(obj):
     return result
 
 def build_a_status_from_obj(obj,accountId):
+    #print "build_a_status_from_obj"
     result = {}
     for att in STATUS_ATT_NAMES:
         try:
             result[att]=getattr(obj,att)
         except AttributeError:
+            #print att
             result[att]=None
     result["if_gap"]=0
     result["if_friends"]=0
@@ -287,13 +307,15 @@ def build_a_status_from_obj(obj,accountId):
     result["if_mentions"]=0
     result["if_comments"]=0
     result["account"]=accountId
-    if result["user"]==None:
+    #if result["user"]==None:
         #for sina DM,there is no user but a sender.
-        result["user"]=getattr(obj,"sender")
+    #    result["user"]=getattr(obj,"sender")
     user=build_a_user_from_obj(result["user"],accountId)
     result["user"]=user
     result["author"]=user
     result["if_rt"]=False
+    result["cm_num"]=0
+    result["rt_num"]=0
     
     # FUck SInA ApI!!!
     
@@ -305,14 +327,35 @@ def build_a_status_from_obj(obj,accountId):
     #result["if_dm"]=getattr(obj,"status")["id"]
     #print "FucK SinA"
     #print result["if_dm"]
-    
+
     rt=result["retweeted_status"]
     if rt!=None:
         rtStatus=build_a_status_from_obj(rt,accountId)
         rtStatus["if_rt"]=True
         result["retweeted_status"]=rtStatus
+
+    s=result["status"]
+    if s!=None:
+        sStatus=build_a_status_from_obj(s,accountId)
+        sStatus["if_cs"]=True
+        result["status"]=sStatus
+        
+    reply_comment=result["reply_comment"]
+    if reply_comment!=None:
+        reply_commentStatus=build_a_status_from_obj(reply_comment,accountId)
+        result["reply_comment"]=reply_commentStatus
+                
     return result
-    
+
+def build_a_count_from_obj(obj,accountId):
+    result = {}
+    for att in STATUS_ATT_COUNTS:
+        try:
+            result[att]=getattr(obj,att)
+        except AttributeError:
+            result[att]=None
+    return result        
+
 def dump(obj):
     for attr in dir(obj):
         print "obj.%s = %s" % (attr, getattr(obj, attr))
@@ -354,6 +397,9 @@ def build_a_status_from_obj_qq(obj,accountId):
     result["if_mentions"]=0
     result["if_comments"]=0
     result["account"]=accountId
+
+    result["cm_num"] = obj["mcount"]
+    result["rt_num"] = obj["count"]
     
     user=build_a_user_from_obj_qq(obj,accountId)
     result["user"]=user
@@ -365,6 +411,9 @@ def build_a_status_from_obj_qq(obj,accountId):
         rtStatus["if_rt"]=True
         
         result["retweeted_status"]=rtStatus
+
+    result["status"]=None
+    result["reply_comment"]=None
     
     return result
 
@@ -427,8 +476,9 @@ def toASCII(s):
     return reduce(lambda x,y:x+y, lst)
     
 def toDateTime(strTimestamp):
-    ltime=time.localtime(strTimestamp)
-    return time.strftime("%Y-%m-%d %H:%M:%S", ltime)
+    #ltime=time.localtime(strTimestamp)
+    #return time.strftime("%Y-%m-%d %H:%M:%S", ltime)
+    return datetime.fromtimestamp(strTimestamp)
 
 
 def get_last_update_time_by_timeline_type(account,timelineType):
@@ -593,7 +643,11 @@ CREATE TABLE [status]
 [if_dm] BOOLEAN,
 [if_mentions] BOOLEAN,
 [if_comments] BOOLEAN,
-[if_gap] BOOLEAN
+[if_gap] BOOLEAN,
+[cm_num] INTEGER,
+[rt_num] INTEGER,
+[status] INTEGER,
+[reply_comment] INTEGER
 )
 """
 
