@@ -1,6 +1,6 @@
+#!/usr/bin/env python2.5
 # -*- coding: utf-8 -*-
 
-
 __author__="Michael/Binkcn/l32606"
 __date__ ="$2011-09-04$"
 
@@ -23,6 +23,7 @@ from weibopy.error import WeibopError
 #from qqweibo.error import QWeiboError
 from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from flickcharm import FlickCharm
+import shutil
 
 
 # Define some constants
@@ -36,6 +37,11 @@ MCE_REQUEST_PATH =  '/com/nokia/mce/request'
 MCE_REQUEST_IF = 'com.nokia.mce.request'
 MCE_DEVICE_ORIENTATION_GET = 'get_device_orientation'
 
+SH_DBUS_NAME  ="cn.l32606.maebo"
+SH_DBUS_IFACE ="cn.l32606.maebo"
+SH_DBUS_PATH  ="/cn/l32606/maebo"
+SH_SHARE_SIG  ="send_via_service"
+
 class MaoboApp(QApplication):
     def __init__(self, parent=None):
         self.logger = logging.getLogger('maebo')
@@ -88,7 +94,6 @@ class MaoboApp(QApplication):
         self.accountsManaForm=None
         self.newAccountForm=None
 
-        Utils.g_orietation=self.get_current_orientation()
 
     # Get the system bus
         sysbus=dbus.Bus.get_system()
@@ -96,11 +101,74 @@ class MaoboApp(QApplication):
     # Connect the "handler" to the orientation changed signal of mce
         sysbus.add_signal_receiver(self.OrientationHandler, signal_name=MCE_SIGNAL_NAME, dbus_interface=MCE_SIGNAL_IFACE, path=MCE_SIGNAL_PATH)
 
+        self.osso_c = osso.Context(SH_DBUS_NAME,"0.0.1",False)
+        self.osso_rpc = osso.Rpc(self.osso_c)
+        self.osso_rpc.set_rpc_callback(SH_DBUS_NAME, SH_DBUS_PATH, SH_DBUS_IFACE, self.send_via_service, self.osso_c)
+
+        self.sendersina_service=SenderSina(self.show_notice)
+        self.senderqq_service=SenderQQ(self.show_notice)
+
+        self.clean_temp_images("/home/user/.sharing/outbox")
+        
+        Utils.g_orietation=self.get_current_orientation()
+        
         if len(self.accounts)==0:
             self.defaultWin.show()
         else:
             self.accountsWin.show()
             
+    def send_via_service(self, interface, method, args, user_data):
+
+        print "send_via_service"
+        
+        if method == SH_SHARE_SIG:
+            print args[0], args[1],args[2], args[3]
+
+            dst_file = args[0] + ".jpg"
+            shutil.copyfile(args[0], dst_file)  
+            
+            param={}
+            param["status"]=""
+            if args[1] != "":
+                param["status"] = args[1] + ": "
+            param["status"]=param["status"]+args[2]
+            
+            if dst_file != None:
+                param["pic"] = dst_file
+
+            param["timelineType"] = None
+            
+            for account in self.accounts:
+                if account["nickname"] == args[3]:
+                    if account["website"]==1:
+                        sender=self.sendersina_service
+                    else:
+                        sender=self.senderqq_service
+            
+                    try:
+                        sender.OAuth(account["username"], account["password"])
+                    except WeibopError,we:
+                        self.show_notice(we)
+                        
+                    sender.initialize(account["id"],param)
+        
+                    self.show_notice("微博发送中...")
+                    sender.start()                        
+        else:
+            print "Not support"
+            return
+            
+    def clean_temp_images(self, outbox_path):
+        if os.path.isdir(outbox_path):
+            paths = os.listdir(outbox_path)
+            for path in paths:
+                filePath = os.path.join(outbox_path, path)
+                if os.path.isfile(filePath):
+                    try:
+                        os.remove(filePath)
+                    except os.error:
+                        continue
+ 
     def get_current_orientation(self):
         '''
         f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
@@ -114,11 +182,11 @@ class MaoboApp(QApplication):
             print "portrait"
             return 1#PORTRAIT
        '''            
-        osso_c = osso.Context("Maebo","0.0.1",False) 
+        #osso_c = osso.Context(SH_DBUS_NAME,"0.0.1",False) 
         orientation=None
 
-        rpc = osso.Rpc(osso_c)
-        orientation =rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_ORIENTATION_GET,
+        #rpc = osso.Rpc(osso_c)
+        orientation =self.osso_rpc.rpc_run(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_ORIENTATION_GET,
             wait_reply=True, use_system_bus=True)       
             
         if orientation == 'landscape': 
@@ -680,8 +748,8 @@ class MaoboApp(QApplication):
         pass
 
     def show_status_window(self,status):
-        print "show_status_window"    
-        print status["id"]
+        #print "show_status_window"    
+        #print status["id"]
         
         #if self.statusWin.status == None or self.statusWin.status["id"]!=status["id"]:
         self.statusWin.status=status
