@@ -143,7 +143,7 @@ def bind_api(**config):
                         self.method, self.headers, self.parameters
                     )
                 try:
-                    print str(time.time())+ " get/post " + url_full
+                    #print str(time.time())+ " get/post " + url_full
                     if self.method == 'POST':
                         req = Request(url_full, data=self.post_data, headers=self.headers)
                         #print str(time.time())+ " post data" + self.post_data
